dlib-face-recognition-sys 19.22.0-rc.2

Unofficial Rust wrappers to the C++ library dlib, face recognition tools
docs.rs failed to build dlib-face-recognition-sys-19.22.0-rc.2
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.

dlib-face-recognition-sys

Automatic building of native dlib .

Publishing

cargo publish --no-default-features